==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/RoutePortFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RoutePortFluentImpl<A extends io.fabric8.openshift.api.model.RoutePortFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.RoutePortFluent<A>{
  public RoutePortFluentImpl() {
  }
  public RoutePortFluentImpl(io.fabric8.openshift.api.model.RoutePort instance) {
    this.withTargetPort(instance.getTargetPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder targetPort;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildTargetPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getTargetPort() {
    return this.targetPort!=null?this.targetPort.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildTargetPort() {
    return this.targetPort!=null?this.targetPort.build():null;
  }
  public A withTargetPort(io.fabric8.kubernetes.api.model.IntOrString targetPort) {
    _visitables.get("targetPort").remove(this.targetPort);
    if (targetPort!=null){ this.targetPort= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(targetPort); _visitables.get("targetPort").add(this.targetPort);} return (A) this;
  }
  public java.lang.Boolean hasTargetPort() {
    return this.targetPort != null;
  }
  public A withNewTargetPort(java.lang.Integer intVal) {
    return (A)withTargetPort(new IntOrString(intVal));
  }
  public A withNewTargetPort(java.lang.String strVal) {
    return (A)withTargetPort(new IntOrString(strVal));
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> withNewTargetPort() {
    return new io.fabric8.openshift.api.model.RoutePortFluentImpl.TargetPortNestedImpl();
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> withNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.openshift.api.model.RoutePortFluentImpl.TargetPortNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> editTargetPort() {
    return withNewTargetPortLike(getTargetPort());
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> editOrNewTargetPort() {
    return withNewTargetPortLike(getTargetPort() != null ? getTargetPort(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> editOrNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewTargetPortLike(getTargetPort() != null ? getTargetPort(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RoutePortFluentImpl that = (RoutePortFluentImpl) o;
    if (targetPort != null ? !targetPort.equals(that.targetPort) :that.targetPort != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(targetPort,  additionalProperties,  super.hashCode());
  }
  public class TargetPortNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<N>> implements io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TargetPortNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    TargetPortNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) RoutePortFluentImpl.this.withTargetPort(builder.build());
    }
    public N endTargetPort() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/RoutePortFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class RoutePortFluentImpl<A extends io.fabric8.openshift.api.model.RoutePortFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.RoutePortFluent<A>{
  public RoutePortFluentImpl() {
  }
  public RoutePortFluentImpl(io.fabric8.openshift.api.model.RoutePort instance) {
    this.withTargetPort(instance.getTargetPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.IntOrStringBuilder targetPort;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildTargetPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getTargetPort() {
    return this.targetPort!=null?this.targetPort.build():null;
  }
  public io.fabric8.kubernetes.api.model.IntOrString buildTargetPort() {
    return this.targetPort!=null?this.targetPort.build():null;
  }
  public A withTargetPort(io.fabric8.kubernetes.api.model.IntOrString targetPort) {
    _visitables.get("targetPort").remove(this.targetPort);
    if (targetPort!=null){ this.targetPort= new io.fabric8.kubernetes.api.model.IntOrStringBuilder(targetPort); _visitables.get("targetPort").add(this.targetPort);} return (A) this;
  }
  public java.lang.Boolean hasTargetPort() {
    return this.targetPort != null;
  }
  public A withNewTargetPort(java.lang.Integer intVal) {
    return (A)withTargetPort(new IntOrString(intVal));
  }
  public A withNewTargetPort(java.lang.String strVal) {
    return (A)withTargetPort(new IntOrString(strVal));
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> withNewTargetPort() {
    return new io.fabric8.openshift.api.model.RoutePortFluentImpl.TargetPortNestedImpl();
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> withNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return new io.fabric8.openshift.api.model.RoutePortFluentImpl.TargetPortNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> editTargetPort() {
    return withNewTargetPortLike(getTargetPort());
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> editOrNewTargetPort() {
    return withNewTargetPortLike(getTargetPort() != null ? getTargetPort(): new io.fabric8.kubernetes.api.model.IntOrStringBuilder().build());
  }
  public io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<A> editOrNewTargetPortLike(io.fabric8.kubernetes.api.model.IntOrString item) {
    return withNewTargetPortLike(getTargetPort() != null ? getTargetPort(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RoutePortFluentImpl that = (RoutePortFluentImpl) o;
    if (targetPort != null ? !targetPort.equals(that.targetPort) :that.targetPort != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(targetPort,  additionalProperties,  super.hashCode());
  }
  public class TargetPortNestedImpl<N> extends io.fabric8.kubernetes.api.model.IntOrStringFluentImpl<io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<N>> implements io.fabric8.openshift.api.model.RoutePortFluent.TargetPortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TargetPortNestedImpl(io.fabric8.kubernetes.api.model.IntOrString item) {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this, item);
    }
    TargetPortNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.IntOrStringBuilder(this);
    }
    io.fabric8.kubernetes.api.model.IntOrStringBuilder builder;
    public N and() {
      return (N) RoutePortFluentImpl.this.withTargetPort(builder.build());
    }
    public N endTargetPort() {
      return and();
    }
    
  }
  
}
